@@ -1,3 +1,10 @@
+#' Function to calculate the conditional log-likelihood
+#' 
+#' @param object An object of class \code{merMod} either fitted by
+#' \code{\link[lme4]{lmer}} or \code{\link[lme4]{glmer}} of the 'lme4' package.
+#' 
+#' @return conditional log-likelihood value
+#' @export
 getcondLL <-
 function(object) {
   # A function that calls the bias correction functions.
@@ -11,7 +18,7 @@ function(object) {
   switch(family(object)$family,
     binomial = {
       cll <- sum(dbinom(x    = getME(object, "y"), 
-                        size = length(unique(getME(object, "y"))), 
+                        size = length(unique(getME(object, "y"))) - 1, 
                         prob = getME(object, "mu"), log = TRUE))
     },
     poisson  = {
